==> suir-component-mapper-3.12.0.tgz: package/esm/radio/radio.js <==
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import FormRadio from "semantic-ui-react/dist/es/collections/Form/FormRadio.js";
import FormField from "semantic-ui-react/dist/es/collections/Form/FormField.js";
import { wrapperProps } from '@data-driven-forms/common/multiple-choice-list';
import FormFieldGrid from '../form-field-grid/form-field-grid';
import { validationError, validationWarning } from '../helpers/helpers';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";

var RadioOption = function RadioOption(_ref) {
  var name = _ref.name,
      option = _ref.option,
      isDisabled = _ref.isDisabled,
      isReadOnly = _ref.isReadOnly,
      props = _objectWithoutProperties(_ref, ["name", "option", "isDisabled", "isReadOnly"]);

  var _useFieldApi = useFieldApi({
    name: name,
    type: 'radio',
    value: option.value
  }),
      input = _useFieldApi.input;

  return /*#__PURE__*/React.createElement(FormRadio, _extends({}, input, {
    disabled: isDisabled,
    onChange: function onChange(_event, data) {
      input.onChange({
        target: data,
        type: 'radio'
      });
    }
  }, props, {
    label: option.label
  }));
};

RadioOption.propTypes = {
  name: PropTypes.string.isRequired,
  option: PropTypes.shape({
    label: PropTypes.node.isRequired,
    value: PropTypes.any.isRequired
  }).isRequired,
  isReadOnly: PropTypes.bool,
  isDisabled: PropTypes.bool
};

var Radio = function Radio(_ref2) {
  var name = _ref2.name,
      props = _objectWithoutProperties(_ref2, ["name"]);

  var _useFieldApi2 = useFieldApi(_objectSpread(_objectSpread({}, props), {}, {
    name: name,
    type: 'radio'
  })),
      options = _useFieldApi2.options,
      isDisabled = _useFieldApi2.isDisabled,
      label = _useFieldApi2.label,
      isRequired = _useFieldApi2.isRequired,
      helperText = _useFieldApi2.helperText,
      description = _useFieldApi2.description,
      isReadOnly = _useFieldApi2.isReadOnly,
      meta = _useFieldApi2.meta,
      validateOnMount = _useFieldApi2.validateOnMount,
      FormFieldGridProps = _useFieldApi2.FormFieldGridProps,
      FormFieldProps = _useFieldApi2.FormFieldProps,
      HelperTextProps = _useFieldApi2.HelperTextProps,
      rest = _objectWithoutProperties(_useFieldApi2, ["options", "isDisabled", "label", "isRequired", "helperText", "description", "isReadOnly", "meta", "validateOnMount", "FormFieldGridProps", "FormFieldProps", "HelperTextProps"]);

  var invalid = validationError(meta, validateOnMount);
  return /*#__PURE__*/React.createElement(FormFieldGrid, _extends({
    helperText: validationWarning(meta, validateOnMount) || helperText,
    HelperTextProps: HelperTextProps
  }, FormFieldGridProps), /*#__PURE__*/React.createElement(FormField, _extends({}, FormFieldProps, {
    disabled: isDisabled,
    required: isRequired,
    error: invalid && {
      content: meta.error || meta.submitError
    },
    label: label
  })), options.map(function (option) {
    return /*#__PURE__*/React.createElement(RadioOption, _extends({
      key: option.value,
      name: name,
      option: option,
      isDisabled: isDisabled,
      isReadOnly: isReadOnly
    }, rest));
  }));
};

Radio.propTypes = _objectSpread(_objectSpread({}, wrapperProps), {}, {
  options: PropTypes.arrayOf(PropTypes.shape({
    value: PropTypes.any,
    label: PropTypes.node
  })),
  label: PropTypes.node.isRequired,
  isDisabled: PropTypes.bool,
  children: PropTypes.any,
  description: PropTypes.node,

  /** Sub components customization API */
  FormFieldGridProps: PropTypes.object,
  FormFieldProps: PropTypes.object,
  HelperTextProps: PropTypes.object
});
Radio.defaultProps = {
  options: [],
  FormFieldGridProps: {},
  FormFieldProps: {},
  HelperTextProps: {}
};
export default Radio;

==> suir-component-mapper-3.16.0.tgz: package/esm/radio/radio.js <==
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["name", "option", "isDisabled", "isReadOnly"],
    _excluded2 = ["name"],
    _excluded3 = ["options", "isDisabled", "label", "isRequired", "helperText", "description", "isReadOnly", "meta", "validateOnMount", "FormFieldGridProps", "FormFieldProps", "HelperTextProps"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import FormRadio from "semantic-ui-react/dist/es/collections/Form/FormRadio.js";
import FormField from "semantic-ui-react/dist/es/collections/Form/FormField.js";
import { wrapperProps } from '@data-driven-forms/common/multiple-choice-list';
import FormFieldGrid from '../form-field-grid/form-field-grid';
import { validationError, validationWarning } from '../helpers/helpers';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";

var RadioOption = function RadioOption(_ref) {
  var name = _ref.name,
      option = _ref.option,
      isDisabled = _ref.isDisabled,
      isReadOnly = _ref.isReadOnly,
      props = _objectWithoutProperties(_ref, _excluded);

  var _useFieldApi = useFieldApi({
    name: name,
    type: 'radio',
    value: option.value
  }),
      input = _useFieldApi.input;

  return /*#__PURE__*/React.createElement(FormRadio, _extends({}, input, {
    disabled: isDisabled,
    onChange: function onChange(_event, data) {
      input.onChange({
        target: data,
        type: 'radio'
      });
    }
  }, props, {
    label: option.label
  }));
};

RadioOption.propTypes = {
  name: PropTypes.string.isRequired,
  option: PropTypes.shape({
    label: PropTypes.node.isRequired,
    value: PropTypes.any.isRequired
  }).isRequired,
  isReadOnly: PropTypes.bool,
  isDisabled: PropTypes.bool
};

var Radio = function Radio(_ref2) {
  var name = _ref2.name,
      props = _objectWithoutProperties(_ref2, _excluded2);

  var _useFieldApi2 = useFieldApi(_objectSpread(_objectSpread({}, props), {}, {
    name: name,
    type: 'radio'
  })),
      options = _useFieldApi2.options,
      isDisabled = _useFieldApi2.isDisabled,
      label = _useFieldApi2.label,
      isRequired = _useFieldApi2.isRequired,
      helperText = _useFieldApi2.helperText,
      description = _useFieldApi2.description,
      isReadOnly = _useFieldApi2.isReadOnly,
      meta = _useFieldApi2.meta,
      validateOnMount = _useFieldApi2.validateOnMount,
      FormFieldGridProps = _useFieldApi2.FormFieldGridProps,
      FormFieldProps = _useFieldApi2.FormFieldProps,
      HelperTextProps = _useFieldApi2.HelperTextProps,
      rest = _objectWithoutProperties(_useFieldApi2, _excluded3);

  var invalid = validationError(meta, validateOnMount);
  return /*#__PURE__*/React.createElement(FormFieldGrid, _extends({
    helperText: validationWarning(meta, validateOnMount) || helperText,
    HelperTextProps: HelperTextProps
  }, FormFieldGridProps), /*#__PURE__*/React.createElement(FormField, _extends({}, FormFieldProps, {
    disabled: isDisabled,
    required: isRequired,
    error: invalid && {
      content: meta.error || meta.submitError
    },
    label: label
  })), options.map(function (option) {
    return /*#__PURE__*/React.createElement(RadioOption, _extends({
      key: option.value,
      name: name,
      option: option,
      isDisabled: isDisabled,
      isReadOnly: isReadOnly
    }, rest));
  }));
};

Radio.propTypes = _objectSpread(_objectSpread({}, wrapperProps), {}, {
  options: PropTypes.arrayOf(PropTypes.shape({
    value: PropTypes.any,
    label: PropTypes.node
  })),
  label: PropTypes.node.isRequired,
  isDisabled: PropTypes.bool,
  children: PropTypes.any,
  description: PropTypes.node,

  /** Sub components customization API */
  FormFieldGridProps: PropTypes.object,
  FormFieldProps: PropTypes.object,
  HelperTextProps: PropTypes.object
});
Radio.defaultProps = {
  options: [],
  FormFieldGridProps: {},
  FormFieldProps: {},
  HelperTextProps: {}
};
export default Radio;
